# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['CommandArgs', 'Command']

@pulumi.input_type
class CommandArgs:
    def __init__(__self__, *,
                 command_content: pulumi.Input[builtins.str],
                 name: pulumi.Input[builtins.str],
                 type: pulumi.Input[builtins.str],
                 content_encoding: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_parameter: Optional[pulumi.Input[builtins.bool]] = None,
                 parameter_definitions: Optional[pulumi.Input[Sequence[pulumi.Input['CommandParameterDefinitionArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CommandTagArgs']]]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 working_dir: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a Command resource.
        :param pulumi.Input[builtins.str] command_content: 命令内容。请根据ContentEncoding参数传入相应命令内容。命令内容不能超过16KB。
        :param pulumi.Input[builtins.str] name: 命令名称。字符长度1~32。不限制特殊字符。
        :param pulumi.Input[builtins.str] type: 命令的类型。Shell：表示创建一个在Linux实例中运行的Shell脚本。Python：表示创建一个Python脚本。Bat：表示创建一个Bat脚本。PowerShell：表示创建一个PowerShell脚本。
        :param pulumi.Input[builtins.str] content_encoding: 命令内容是否经过Base64编码处理。Base64（默认）：经过Base64编码处理。PlainText： 未进行编码处理。
        :param pulumi.Input[builtins.str] description: 命令描述，默认为空字符串。字符长度0~256。不限制特殊字符。
        :param pulumi.Input[builtins.bool] enable_parameter: 创建的命令是否使用自定义参数。false：默认，表示不使用自定义参数。true：表示使用自定义参数。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。
        :param pulumi.Input[builtins.int] timeout: 创建的命令在ECS实例中执行时最大的超时时间，单位为秒。取值范围：30~86400。默认值：60。
        :param pulumi.Input[builtins.str] username: 执行命令时的用户名。
        :param pulumi.Input[builtins.str] working_dir: 创建的命令在ECS实例中运行的目录。
        """
        pulumi.set(__self__, "command_content", command_content)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "type", type)
        if content_encoding is not None:
            pulumi.set(__self__, "content_encoding", content_encoding)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_parameter is not None:
            pulumi.set(__self__, "enable_parameter", enable_parameter)
        if parameter_definitions is not None:
            pulumi.set(__self__, "parameter_definitions", parameter_definitions)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if working_dir is not None:
            pulumi.set(__self__, "working_dir", working_dir)

    @property
    @pulumi.getter(name="commandContent")
    def command_content(self) -> pulumi.Input[builtins.str]:
        """
        命令内容。请根据ContentEncoding参数传入相应命令内容。命令内容不能超过16KB。
        """
        return pulumi.get(self, "command_content")

    @command_content.setter
    def command_content(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "command_content", value)

    @property
    @pulumi.getter
    def name(self) -> pulumi.Input[builtins.str]:
        """
        命令名称。字符长度1~32。不限制特殊字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def type(self) -> pulumi.Input[builtins.str]:
        """
        命令的类型。Shell：表示创建一个在Linux实例中运行的Shell脚本。Python：表示创建一个Python脚本。Bat：表示创建一个Bat脚本。PowerShell：表示创建一个PowerShell脚本。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="contentEncoding")
    def content_encoding(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令内容是否经过Base64编码处理。Base64（默认）：经过Base64编码处理。PlainText： 未进行编码处理。
        """
        return pulumi.get(self, "content_encoding")

    @content_encoding.setter
    def content_encoding(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "content_encoding", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令描述，默认为空字符串。字符长度0~256。不限制特殊字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableParameter")
    def enable_parameter(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        创建的命令是否使用自定义参数。false：默认，表示不使用自定义参数。true：表示使用自定义参数。
        """
        return pulumi.get(self, "enable_parameter")

    @enable_parameter.setter
    def enable_parameter(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_parameter", value)

    @property
    @pulumi.getter(name="parameterDefinitions")
    def parameter_definitions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CommandParameterDefinitionArgs']]]]:
        return pulumi.get(self, "parameter_definitions")

    @parameter_definitions.setter
    def parameter_definitions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CommandParameterDefinitionArgs']]]]):
        pulumi.set(self, "parameter_definitions", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源所属项目，一个资源只能归属于一个项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CommandTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CommandTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        创建的命令在ECS实例中执行时最大的超时时间，单位为秒。取值范围：30~86400。默认值：60。
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "timeout", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        执行命令时的用户名。
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="workingDir")
    def working_dir(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建的命令在ECS实例中运行的目录。
        """
        return pulumi.get(self, "working_dir")

    @working_dir.setter
    def working_dir(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "working_dir", value)


@pulumi.input_type
class _CommandState:
    def __init__(__self__, *,
                 command_content: Optional[pulumi.Input[builtins.str]] = None,
                 command_id: Optional[pulumi.Input[builtins.str]] = None,
                 content_encoding: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_parameter: Optional[pulumi.Input[builtins.bool]] = None,
                 invocation_times: Optional[pulumi.Input[builtins.int]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 parameter_definitions: Optional[pulumi.Input[Sequence[pulumi.Input['CommandParameterDefinitionArgs']]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 provider_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['CommandTagArgs']]]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 working_dir: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Command resources.
        :param pulumi.Input[builtins.str] command_content: 命令内容。请根据ContentEncoding参数传入相应命令内容。命令内容不能超过16KB。
        :param pulumi.Input[builtins.str] command_id: 自定义命令ID。
        :param pulumi.Input[builtins.str] content_encoding: 命令内容是否经过Base64编码处理。Base64（默认）：经过Base64编码处理。PlainText： 未进行编码处理。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 命令描述，默认为空字符串。字符长度0~256。不限制特殊字符。
        :param pulumi.Input[builtins.bool] enable_parameter: 创建的命令是否使用自定义参数。false：默认，表示不使用自定义参数。true：表示使用自定义参数。
        :param pulumi.Input[builtins.int] invocation_times: 命令被调用次数。
        :param pulumi.Input[builtins.str] name: 命令名称。字符长度1~32。不限制特殊字符。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。
        :param pulumi.Input[builtins.str] provider_name: 命令的提供方。
        :param pulumi.Input[builtins.int] timeout: 创建的命令在ECS实例中执行时最大的超时时间，单位为秒。取值范围：30~86400。默认值：60。
        :param pulumi.Input[builtins.str] type: 命令的类型。Shell：表示创建一个在Linux实例中运行的Shell脚本。Python：表示创建一个Python脚本。Bat：表示创建一个Bat脚本。PowerShell：表示创建一个PowerShell脚本。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] username: 执行命令时的用户名。
        :param pulumi.Input[builtins.str] working_dir: 创建的命令在ECS实例中运行的目录。
        """
        if command_content is not None:
            pulumi.set(__self__, "command_content", command_content)
        if command_id is not None:
            pulumi.set(__self__, "command_id", command_id)
        if content_encoding is not None:
            pulumi.set(__self__, "content_encoding", content_encoding)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_parameter is not None:
            pulumi.set(__self__, "enable_parameter", enable_parameter)
        if invocation_times is not None:
            pulumi.set(__self__, "invocation_times", invocation_times)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if parameter_definitions is not None:
            pulumi.set(__self__, "parameter_definitions", parameter_definitions)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if provider_name is not None:
            pulumi.set(__self__, "provider_name", provider_name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if username is not None:
            pulumi.set(__self__, "username", username)
        if working_dir is not None:
            pulumi.set(__self__, "working_dir", working_dir)

    @property
    @pulumi.getter(name="commandContent")
    def command_content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令内容。请根据ContentEncoding参数传入相应命令内容。命令内容不能超过16KB。
        """
        return pulumi.get(self, "command_content")

    @command_content.setter
    def command_content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "command_content", value)

    @property
    @pulumi.getter(name="commandId")
    def command_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        自定义命令ID。
        """
        return pulumi.get(self, "command_id")

    @command_id.setter
    def command_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "command_id", value)

    @property
    @pulumi.getter(name="contentEncoding")
    def content_encoding(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令内容是否经过Base64编码处理。Base64（默认）：经过Base64编码处理。PlainText： 未进行编码处理。
        """
        return pulumi.get(self, "content_encoding")

    @content_encoding.setter
    def content_encoding(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "content_encoding", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令描述，默认为空字符串。字符长度0~256。不限制特殊字符。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableParameter")
    def enable_parameter(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        创建的命令是否使用自定义参数。false：默认，表示不使用自定义参数。true：表示使用自定义参数。
        """
        return pulumi.get(self, "enable_parameter")

    @enable_parameter.setter
    def enable_parameter(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_parameter", value)

    @property
    @pulumi.getter(name="invocationTimes")
    def invocation_times(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        命令被调用次数。
        """
        return pulumi.get(self, "invocation_times")

    @invocation_times.setter
    def invocation_times(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "invocation_times", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令名称。字符长度1~32。不限制特殊字符。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="parameterDefinitions")
    def parameter_definitions(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CommandParameterDefinitionArgs']]]]:
        return pulumi.get(self, "parameter_definitions")

    @parameter_definitions.setter
    def parameter_definitions(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CommandParameterDefinitionArgs']]]]):
        pulumi.set(self, "parameter_definitions", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        资源所属项目，一个资源只能归属于一个项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令的提供方。
        """
        return pulumi.get(self, "provider_name")

    @provider_name.setter
    def provider_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "provider_name", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['CommandTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['CommandTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        创建的命令在ECS实例中执行时最大的超时时间，单位为秒。取值范围：30~86400。默认值：60。
        """
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "timeout", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        命令的类型。Shell：表示创建一个在Linux实例中运行的Shell脚本。Python：表示创建一个Python脚本。Bat：表示创建一个Bat脚本。PowerShell：表示创建一个PowerShell脚本。
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter
    def username(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        执行命令时的用户名。
        """
        return pulumi.get(self, "username")

    @username.setter
    def username(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "username", value)

    @property
    @pulumi.getter(name="workingDir")
    def working_dir(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建的命令在ECS实例中运行的目录。
        """
        return pulumi.get(self, "working_dir")

    @working_dir.setter
    def working_dir(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "working_dir", value)


@pulumi.type_token("bytepluscc:ecs/command:Command")
class Command(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 command_content: Optional[pulumi.Input[builtins.str]] = None,
                 content_encoding: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_parameter: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 parameter_definitions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CommandParameterDefinitionArgs', 'CommandParameterDefinitionArgsDict']]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CommandTagArgs', 'CommandTagArgsDict']]]]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 working_dir: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        自定义命令是云助手提供的满足您个性化运维需求的功能，您可以在预置的公共命令不满足需求时创建自定义命令，并通过运维任务在实例中批量执行您编写的自定义命令。

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/command:Command example "command_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] command_content: 命令内容。请根据ContentEncoding参数传入相应命令内容。命令内容不能超过16KB。
        :param pulumi.Input[builtins.str] content_encoding: 命令内容是否经过Base64编码处理。Base64（默认）：经过Base64编码处理。PlainText： 未进行编码处理。
        :param pulumi.Input[builtins.str] description: 命令描述，默认为空字符串。字符长度0~256。不限制特殊字符。
        :param pulumi.Input[builtins.bool] enable_parameter: 创建的命令是否使用自定义参数。false：默认，表示不使用自定义参数。true：表示使用自定义参数。
        :param pulumi.Input[builtins.str] name: 命令名称。字符长度1~32。不限制特殊字符。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。
        :param pulumi.Input[builtins.int] timeout: 创建的命令在ECS实例中执行时最大的超时时间，单位为秒。取值范围：30~86400。默认值：60。
        :param pulumi.Input[builtins.str] type: 命令的类型。Shell：表示创建一个在Linux实例中运行的Shell脚本。Python：表示创建一个Python脚本。Bat：表示创建一个Bat脚本。PowerShell：表示创建一个PowerShell脚本。
        :param pulumi.Input[builtins.str] username: 执行命令时的用户名。
        :param pulumi.Input[builtins.str] working_dir: 创建的命令在ECS实例中运行的目录。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: CommandArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        自定义命令是云助手提供的满足您个性化运维需求的功能，您可以在预置的公共命令不满足需求时创建自定义命令，并通过运维任务在实例中批量执行您编写的自定义命令。

        ## Import

        ```sh
        $ pulumi import bytepluscc:ecs/command:Command example "command_id"
        ```

        :param str resource_name: The name of the resource.
        :param CommandArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(CommandArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 command_content: Optional[pulumi.Input[builtins.str]] = None,
                 content_encoding: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_parameter: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 parameter_definitions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CommandParameterDefinitionArgs', 'CommandParameterDefinitionArgsDict']]]]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CommandTagArgs', 'CommandTagArgsDict']]]]] = None,
                 timeout: Optional[pulumi.Input[builtins.int]] = None,
                 type: Optional[pulumi.Input[builtins.str]] = None,
                 username: Optional[pulumi.Input[builtins.str]] = None,
                 working_dir: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = CommandArgs.__new__(CommandArgs)

            if command_content is None and not opts.urn:
                raise TypeError("Missing required property 'command_content'")
            __props__.__dict__["command_content"] = command_content
            __props__.__dict__["content_encoding"] = content_encoding
            __props__.__dict__["description"] = description
            __props__.__dict__["enable_parameter"] = enable_parameter
            if name is None and not opts.urn:
                raise TypeError("Missing required property 'name'")
            __props__.__dict__["name"] = name
            __props__.__dict__["parameter_definitions"] = parameter_definitions
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["tags"] = tags
            __props__.__dict__["timeout"] = timeout
            if type is None and not opts.urn:
                raise TypeError("Missing required property 'type'")
            __props__.__dict__["type"] = type
            __props__.__dict__["username"] = username
            __props__.__dict__["working_dir"] = working_dir
            __props__.__dict__["command_id"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["invocation_times"] = None
            __props__.__dict__["provider_name"] = None
            __props__.__dict__["updated_time"] = None
        super(Command, __self__).__init__(
            'bytepluscc:ecs/command:Command',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            command_content: Optional[pulumi.Input[builtins.str]] = None,
            command_id: Optional[pulumi.Input[builtins.str]] = None,
            content_encoding: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enable_parameter: Optional[pulumi.Input[builtins.bool]] = None,
            invocation_times: Optional[pulumi.Input[builtins.int]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            parameter_definitions: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CommandParameterDefinitionArgs', 'CommandParameterDefinitionArgsDict']]]]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            provider_name: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['CommandTagArgs', 'CommandTagArgsDict']]]]] = None,
            timeout: Optional[pulumi.Input[builtins.int]] = None,
            type: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            username: Optional[pulumi.Input[builtins.str]] = None,
            working_dir: Optional[pulumi.Input[builtins.str]] = None) -> 'Command':
        """
        Get an existing Command resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] command_content: 命令内容。请根据ContentEncoding参数传入相应命令内容。命令内容不能超过16KB。
        :param pulumi.Input[builtins.str] command_id: 自定义命令ID。
        :param pulumi.Input[builtins.str] content_encoding: 命令内容是否经过Base64编码处理。Base64（默认）：经过Base64编码处理。PlainText： 未进行编码处理。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 命令描述，默认为空字符串。字符长度0~256。不限制特殊字符。
        :param pulumi.Input[builtins.bool] enable_parameter: 创建的命令是否使用自定义参数。false：默认，表示不使用自定义参数。true：表示使用自定义参数。
        :param pulumi.Input[builtins.int] invocation_times: 命令被调用次数。
        :param pulumi.Input[builtins.str] name: 命令名称。字符长度1~32。不限制特殊字符。
        :param pulumi.Input[builtins.str] project_name: 资源所属项目，一个资源只能归属于一个项目。
        :param pulumi.Input[builtins.str] provider_name: 命令的提供方。
        :param pulumi.Input[builtins.int] timeout: 创建的命令在ECS实例中执行时最大的超时时间，单位为秒。取值范围：30~86400。默认值：60。
        :param pulumi.Input[builtins.str] type: 命令的类型。Shell：表示创建一个在Linux实例中运行的Shell脚本。Python：表示创建一个Python脚本。Bat：表示创建一个Bat脚本。PowerShell：表示创建一个PowerShell脚本。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] username: 执行命令时的用户名。
        :param pulumi.Input[builtins.str] working_dir: 创建的命令在ECS实例中运行的目录。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _CommandState.__new__(_CommandState)

        __props__.__dict__["command_content"] = command_content
        __props__.__dict__["command_id"] = command_id
        __props__.__dict__["content_encoding"] = content_encoding
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_parameter"] = enable_parameter
        __props__.__dict__["invocation_times"] = invocation_times
        __props__.__dict__["name"] = name
        __props__.__dict__["parameter_definitions"] = parameter_definitions
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["provider_name"] = provider_name
        __props__.__dict__["tags"] = tags
        __props__.__dict__["timeout"] = timeout
        __props__.__dict__["type"] = type
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["username"] = username
        __props__.__dict__["working_dir"] = working_dir
        return Command(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="commandContent")
    def command_content(self) -> pulumi.Output[builtins.str]:
        """
        命令内容。请根据ContentEncoding参数传入相应命令内容。命令内容不能超过16KB。
        """
        return pulumi.get(self, "command_content")

    @property
    @pulumi.getter(name="commandId")
    def command_id(self) -> pulumi.Output[builtins.str]:
        """
        自定义命令ID。
        """
        return pulumi.get(self, "command_id")

    @property
    @pulumi.getter(name="contentEncoding")
    def content_encoding(self) -> pulumi.Output[builtins.str]:
        """
        命令内容是否经过Base64编码处理。Base64（默认）：经过Base64编码处理。PlainText： 未进行编码处理。
        """
        return pulumi.get(self, "content_encoding")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        命令描述，默认为空字符串。字符长度0~256。不限制特殊字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableParameter")
    def enable_parameter(self) -> pulumi.Output[builtins.bool]:
        """
        创建的命令是否使用自定义参数。false：默认，表示不使用自定义参数。true：表示使用自定义参数。
        """
        return pulumi.get(self, "enable_parameter")

    @property
    @pulumi.getter(name="invocationTimes")
    def invocation_times(self) -> pulumi.Output[builtins.int]:
        """
        命令被调用次数。
        """
        return pulumi.get(self, "invocation_times")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        命令名称。字符长度1~32。不限制特殊字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="parameterDefinitions")
    def parameter_definitions(self) -> pulumi.Output[Sequence['outputs.CommandParameterDefinition']]:
        return pulumi.get(self, "parameter_definitions")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        资源所属项目，一个资源只能归属于一个项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> pulumi.Output[builtins.str]:
        """
        命令的提供方。
        """
        return pulumi.get(self, "provider_name")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.CommandTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def timeout(self) -> pulumi.Output[builtins.int]:
        """
        创建的命令在ECS实例中执行时最大的超时时间，单位为秒。取值范围：30~86400。默认值：60。
        """
        return pulumi.get(self, "timeout")

    @property
    @pulumi.getter
    def type(self) -> pulumi.Output[builtins.str]:
        """
        命令的类型。Shell：表示创建一个在Linux实例中运行的Shell脚本。Python：表示创建一个Python脚本。Bat：表示创建一个Bat脚本。PowerShell：表示创建一个PowerShell脚本。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter
    def username(self) -> pulumi.Output[builtins.str]:
        """
        执行命令时的用户名。
        """
        return pulumi.get(self, "username")

    @property
    @pulumi.getter(name="workingDir")
    def working_dir(self) -> pulumi.Output[builtins.str]:
        """
        创建的命令在ECS实例中运行的目录。
        """
        return pulumi.get(self, "working_dir")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['BandwidthPackageArgs', 'BandwidthPackage']

@pulumi.input_type
class BandwidthPackageArgs:
    def __init__(__self__, *,
                 bandwidth: pulumi.Input[builtins.int],
                 bandwidth_package_name: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageEipAddressArgs']]]] = None,
                 enable_dual_stack: Optional[pulumi.Input[builtins.bool]] = None,
                 isp: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 security_protection_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageTagArgs']]]] = None):
        """
        The set of arguments for constructing a BandwidthPackage resource.
        :param pulumi.Input[builtins.int] bandwidth: 共享带宽包的带宽上限，单位：Mbps。BillingType传入1：取值范围5 ~ 5000，BillingType传入2、3、4：取值范围2 ~ 5000。
        :param pulumi.Input[builtins.str] bandwidth_package_name: 带宽包名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.int] billing_type: 共享带宽包的计费方式。取值如下：1：包年包月。2 : 按带宽上限计费（默认值）。3：按主流量计费。4 : 按传统95计费（保底比例默认20%）。
        :param pulumi.Input[builtins.str] description: 描述信息，长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.bool] enable_dual_stack: 是否启用双栈，取值如下：true：启用双栈。false：不启用双栈。
        :param pulumi.Input[builtins.str] isp: 线路类型，默认为BGP。BGP：BGP（多线）。1、若您的账号已申请并开通了静态单线权限，则可传入如下取值：1.1、ChinaMobile：中国移动静态单线。1.2、ChinaTelecom：中国电信静态单线。1.3、ChinaUnicom：中国联通静态单线。2、若您的账号已申请并开通了BGP单线权限，则可传入SingleLine*BGP。3、若您的账号已申请并开通了精品BGP权限，则可传入Premium*BGP。4、若您的账号已申请并开通了融合BGP权限，则可传入Fusion*BGP。5、若您的账号已申请并开通了惠选型静态单线权限，则可传入如下取值：5.1、ChinaMobile*Value：中国移动惠选型静态单线。5.2、ChinaUnicom*Value：中国联通惠选型静态单线。5.3、ChinaTelecom*Value：中国电信惠选型静态单线。
        :param pulumi.Input[builtins.int] period: 购买包年包月共享带宽包的时长，默认“1”。当PeriodUnit传入1，Period取值范围：1~9、12、24、36。当PeriodUnit传入2，Period取值范围：1～3。
        :param pulumi.Input[builtins.int] period_unit: 购买包年包月共享带宽包时长的单位，取值如下：1：月（默认值）。2 ：年。
        :param pulumi.Input[builtins.str] project_name: 项目名称，不填默认加入default项目。
        :param pulumi.Input[builtins.str] protocol: 共享带宽包的IP协议，取值如下：Dual-stack：双栈协议类型。IPv4：IPv4协议类型协议。仅BillingType传2或4时，本参数支持传入Dual-stack
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_protection_types: 共享带宽包的的安全防护类型。AntiDDoS_Enhanced：创建增强防护类型的共享带宽包，即创建支持添加基础防护类型公网IP的共享带宽包。不填则表示基础防护类型的共享带宽包，即创建支持添加增强防护类型公网IP的共享带宽包。
        """
        pulumi.set(__self__, "bandwidth", bandwidth)
        if bandwidth_package_name is not None:
            pulumi.set(__self__, "bandwidth_package_name", bandwidth_package_name)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip_addresses is not None:
            pulumi.set(__self__, "eip_addresses", eip_addresses)
        if enable_dual_stack is not None:
            pulumi.set(__self__, "enable_dual_stack", enable_dual_stack)
        if isp is not None:
            pulumi.set(__self__, "isp", isp)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if security_protection_types is not None:
            pulumi.set(__self__, "security_protection_types", security_protection_types)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Input[builtins.int]:
        """
        共享带宽包的带宽上限，单位：Mbps。BillingType传入1：取值范围5 ~ 5000，BillingType传入2、3、4：取值范围2 ~ 5000。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: pulumi.Input[builtins.int]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="bandwidthPackageName")
    def bandwidth_package_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        带宽包名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "bandwidth_package_name")

    @bandwidth_package_name.setter
    def bandwidth_package_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bandwidth_package_name", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        共享带宽包的计费方式。取值如下：1：包年包月。2 : 按带宽上限计费（默认值）。3：按主流量计费。4 : 按传统95计费（保底比例默认20%）。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述信息，长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="eipAddresses")
    def eip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageEipAddressArgs']]]]:
        return pulumi.get(self, "eip_addresses")

    @eip_addresses.setter
    def eip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageEipAddressArgs']]]]):
        pulumi.set(self, "eip_addresses", value)

    @property
    @pulumi.getter(name="enableDualStack")
    def enable_dual_stack(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否启用双栈，取值如下：true：启用双栈。false：不启用双栈。
        """
        return pulumi.get(self, "enable_dual_stack")

    @enable_dual_stack.setter
    def enable_dual_stack(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_dual_stack", value)

    @property
    @pulumi.getter
    def isp(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        线路类型，默认为BGP。BGP：BGP（多线）。1、若您的账号已申请并开通了静态单线权限，则可传入如下取值：1.1、ChinaMobile：中国移动静态单线。1.2、ChinaTelecom：中国电信静态单线。1.3、ChinaUnicom：中国联通静态单线。2、若您的账号已申请并开通了BGP单线权限，则可传入SingleLine*BGP。3、若您的账号已申请并开通了精品BGP权限，则可传入Premium*BGP。4、若您的账号已申请并开通了融合BGP权限，则可传入Fusion*BGP。5、若您的账号已申请并开通了惠选型静态单线权限，则可传入如下取值：5.1、ChinaMobile*Value：中国移动惠选型静态单线。5.2、ChinaUnicom*Value：中国联通惠选型静态单线。5.3、ChinaTelecom*Value：中国电信惠选型静态单线。
        """
        return pulumi.get(self, "isp")

    @isp.setter
    def isp(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "isp", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        购买包年包月共享带宽包的时长，默认“1”。当PeriodUnit传入1，Period取值范围：1~9、12、24、36。当PeriodUnit传入2，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        购买包年包月共享带宽包时长的单位，取值如下：1：月（默认值）。2 ：年。
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称，不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        共享带宽包的IP协议，取值如下：Dual-stack：双栈协议类型。IPv4：IPv4协议类型协议。仅BillingType传2或4时，本参数支持传入Dual-stack
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter(name="securityProtectionTypes")
    def security_protection_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        共享带宽包的的安全防护类型。AntiDDoS_Enhanced：创建增强防护类型的共享带宽包，即创建支持添加基础防护类型公网IP的共享带宽包。不填则表示基础防护类型的共享带宽包，即创建支持添加增强防护类型公网IP的共享带宽包。
        """
        return pulumi.get(self, "security_protection_types")

    @security_protection_types.setter
    def security_protection_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_protection_types", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageTagArgs']]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _BandwidthPackageState:
    def __init__(__self__, *,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
                 bandwidth_package_name: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 business_status: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 deleted_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageEipAddressArgs']]]] = None,
                 enable_dual_stack: Optional[pulumi.Input[builtins.bool]] = None,
                 expired_time: Optional[pulumi.Input[builtins.str]] = None,
                 isp: Optional[pulumi.Input[builtins.str]] = None,
                 overdue_time: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 ratio: Optional[pulumi.Input[builtins.int]] = None,
                 security_protection_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageTagArgs']]]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering BandwidthPackage resources.
        :param pulumi.Input[builtins.int] bandwidth: 共享带宽包的带宽上限，单位：Mbps。BillingType传入1：取值范围5 ~ 5000，BillingType传入2、3、4：取值范围2 ~ 5000。
        :param pulumi.Input[builtins.str] bandwidth_package_id: 带宽包ID
        :param pulumi.Input[builtins.str] bandwidth_package_name: 带宽包名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.int] billing_type: 共享带宽包的计费方式。取值如下：1：包年包月。2 : 按带宽上限计费（默认值）。3：按主流量计费。4 : 按传统95计费（保底比例默认20%）。
        :param pulumi.Input[builtins.str] business_status: 计费状态
        :param pulumi.Input[builtins.str] created_time: 创建时间
        :param pulumi.Input[builtins.str] deleted_time: 删除时间
        :param pulumi.Input[builtins.str] description: 描述信息，长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.bool] enable_dual_stack: 是否启用双栈，取值如下：true：启用双栈。false：不启用双栈。
        :param pulumi.Input[builtins.str] expired_time: 过期时间
        :param pulumi.Input[builtins.str] isp: 线路类型，默认为BGP。BGP：BGP（多线）。1、若您的账号已申请并开通了静态单线权限，则可传入如下取值：1.1、ChinaMobile：中国移动静态单线。1.2、ChinaTelecom：中国电信静态单线。1.3、ChinaUnicom：中国联通静态单线。2、若您的账号已申请并开通了BGP单线权限，则可传入SingleLine*BGP。3、若您的账号已申请并开通了精品BGP权限，则可传入Premium*BGP。4、若您的账号已申请并开通了融合BGP权限，则可传入Fusion*BGP。5、若您的账号已申请并开通了惠选型静态单线权限，则可传入如下取值：5.1、ChinaMobile*Value：中国移动惠选型静态单线。5.2、ChinaUnicom*Value：中国联通惠选型静态单线。5.3、ChinaTelecom*Value：中国电信惠选型静态单线。
        :param pulumi.Input[builtins.str] overdue_time: 欠费时间
        :param pulumi.Input[builtins.int] period: 购买包年包月共享带宽包的时长，默认“1”。当PeriodUnit传入1，Period取值范围：1~9、12、24、36。当PeriodUnit传入2，Period取值范围：1～3。
        :param pulumi.Input[builtins.int] period_unit: 购买包年包月共享带宽包时长的单位，取值如下：1：月（默认值）。2 ：年。
        :param pulumi.Input[builtins.str] project_name: 项目名称，不填默认加入default项目。
        :param pulumi.Input[builtins.str] protocol: 共享带宽包的IP协议，取值如下：Dual-stack：双栈协议类型。IPv4：IPv4协议类型协议。仅BillingType传2或4时，本参数支持传入Dual-stack
        :param pulumi.Input[builtins.int] ratio: 95计费保底比例，单位%，仅95计费共享带宽包实例返回此参数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_protection_types: 共享带宽包的的安全防护类型。AntiDDoS_Enhanced：创建增强防护类型的共享带宽包，即创建支持添加基础防护类型公网IP的共享带宽包。不填则表示基础防护类型的共享带宽包，即创建支持添加增强防护类型公网IP的共享带宽包。
        :param pulumi.Input[builtins.str] status: 共享带宽包的状态。Creating：创建中。Available：可用。Deleting：删除中。
        :param pulumi.Input[builtins.str] updated_time: 更新时间
        """
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if bandwidth_package_id is not None:
            pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if bandwidth_package_name is not None:
            pulumi.set(__self__, "bandwidth_package_name", bandwidth_package_name)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if business_status is not None:
            pulumi.set(__self__, "business_status", business_status)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if deleted_time is not None:
            pulumi.set(__self__, "deleted_time", deleted_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip_addresses is not None:
            pulumi.set(__self__, "eip_addresses", eip_addresses)
        if enable_dual_stack is not None:
            pulumi.set(__self__, "enable_dual_stack", enable_dual_stack)
        if expired_time is not None:
            pulumi.set(__self__, "expired_time", expired_time)
        if isp is not None:
            pulumi.set(__self__, "isp", isp)
        if overdue_time is not None:
            pulumi.set(__self__, "overdue_time", overdue_time)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if period_unit is not None:
            pulumi.set(__self__, "period_unit", period_unit)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if protocol is not None:
            pulumi.set(__self__, "protocol", protocol)
        if ratio is not None:
            pulumi.set(__self__, "ratio", ratio)
        if security_protection_types is not None:
            pulumi.set(__self__, "security_protection_types", security_protection_types)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        共享带宽包的带宽上限，单位：Mbps。BillingType传入1：取值范围5 ~ 5000，BillingType传入2、3、4：取值范围2 ~ 5000。
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        带宽包ID
        """
        return pulumi.get(self, "bandwidth_package_id")

    @bandwidth_package_id.setter
    def bandwidth_package_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bandwidth_package_id", value)

    @property
    @pulumi.getter(name="bandwidthPackageName")
    def bandwidth_package_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        带宽包名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "bandwidth_package_name")

    @bandwidth_package_name.setter
    def bandwidth_package_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "bandwidth_package_name", value)

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        共享带宽包的计费方式。取值如下：1：包年包月。2 : 按带宽上限计费（默认值）。3：按主流量计费。4 : 按传统95计费（保底比例默认20%）。
        """
        return pulumi.get(self, "billing_type")

    @billing_type.setter
    def billing_type(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "billing_type", value)

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        计费状态
        """
        return pulumi.get(self, "business_status")

    @business_status.setter
    def business_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "business_status", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        删除时间
        """
        return pulumi.get(self, "deleted_time")

    @deleted_time.setter
    def deleted_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "deleted_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        描述信息，长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="eipAddresses")
    def eip_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageEipAddressArgs']]]]:
        return pulumi.get(self, "eip_addresses")

    @eip_addresses.setter
    def eip_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageEipAddressArgs']]]]):
        pulumi.set(self, "eip_addresses", value)

    @property
    @pulumi.getter(name="enableDualStack")
    def enable_dual_stack(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否启用双栈，取值如下：true：启用双栈。false：不启用双栈。
        """
        return pulumi.get(self, "enable_dual_stack")

    @enable_dual_stack.setter
    def enable_dual_stack(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_dual_stack", value)

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        过期时间
        """
        return pulumi.get(self, "expired_time")

    @expired_time.setter
    def expired_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "expired_time", value)

    @property
    @pulumi.getter
    def isp(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        线路类型，默认为BGP。BGP：BGP（多线）。1、若您的账号已申请并开通了静态单线权限，则可传入如下取值：1.1、ChinaMobile：中国移动静态单线。1.2、ChinaTelecom：中国电信静态单线。1.3、ChinaUnicom：中国联通静态单线。2、若您的账号已申请并开通了BGP单线权限，则可传入SingleLine*BGP。3、若您的账号已申请并开通了精品BGP权限，则可传入Premium*BGP。4、若您的账号已申请并开通了融合BGP权限，则可传入Fusion*BGP。5、若您的账号已申请并开通了惠选型静态单线权限，则可传入如下取值：5.1、ChinaMobile*Value：中国移动惠选型静态单线。5.2、ChinaUnicom*Value：中国联通惠选型静态单线。5.3、ChinaTelecom*Value：中国电信惠选型静态单线。
        """
        return pulumi.get(self, "isp")

    @isp.setter
    def isp(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "isp", value)

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        欠费时间
        """
        return pulumi.get(self, "overdue_time")

    @overdue_time.setter
    def overdue_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "overdue_time", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        购买包年包月共享带宽包的时长，默认“1”。当PeriodUnit传入1，Period取值范围：1~9、12、24、36。当PeriodUnit传入2，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        购买包年包月共享带宽包时长的单位，取值如下：1：月（默认值）。2 ：年。
        """
        return pulumi.get(self, "period_unit")

    @period_unit.setter
    def period_unit(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "period_unit", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        项目名称，不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter
    def protocol(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        共享带宽包的IP协议，取值如下：Dual-stack：双栈协议类型。IPv4：IPv4协议类型协议。仅BillingType传2或4时，本参数支持传入Dual-stack
        """
        return pulumi.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "protocol", value)

    @property
    @pulumi.getter
    def ratio(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        95计费保底比例，单位%，仅95计费共享带宽包实例返回此参数。
        """
        return pulumi.get(self, "ratio")

    @ratio.setter
    def ratio(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ratio", value)

    @property
    @pulumi.getter(name="securityProtectionTypes")
    def security_protection_types(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        共享带宽包的的安全防护类型。AntiDDoS_Enhanced：创建增强防护类型的共享带宽包，即创建支持添加基础防护类型公网IP的共享带宽包。不填则表示基础防护类型的共享带宽包，即创建支持添加增强防护类型公网IP的共享带宽包。
        """
        return pulumi.get(self, "security_protection_types")

    @security_protection_types.setter
    def security_protection_types(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_protection_types", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        共享带宽包的状态。Creating：创建中。Available：可用。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['BandwidthPackageTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)


@pulumi.type_token("bytepluscc:vpc/bandwidthPackage:BandwidthPackage")
class BandwidthPackage(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_package_name: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BandwidthPackageEipAddressArgs', 'BandwidthPackageEipAddressArgsDict']]]]] = None,
                 enable_dual_stack: Optional[pulumi.Input[builtins.bool]] = None,
                 isp: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 security_protection_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BandwidthPackageTagArgs', 'BandwidthPackageTagArgsDict']]]]] = None,
                 __props__=None):
        """
        共享带宽包是一种支持复用和共享带宽的云资源。将单个地域内多个公网IP或IPv6公网带宽添加到一个共享带宽包实例中，共享一条带宽。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/bandwidthPackage:BandwidthPackage example "bandwidth_package_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] bandwidth: 共享带宽包的带宽上限，单位：Mbps。BillingType传入1：取值范围5 ~ 5000，BillingType传入2、3、4：取值范围2 ~ 5000。
        :param pulumi.Input[builtins.str] bandwidth_package_name: 带宽包名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.int] billing_type: 共享带宽包的计费方式。取值如下：1：包年包月。2 : 按带宽上限计费（默认值）。3：按主流量计费。4 : 按传统95计费（保底比例默认20%）。
        :param pulumi.Input[builtins.str] description: 描述信息，长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.bool] enable_dual_stack: 是否启用双栈，取值如下：true：启用双栈。false：不启用双栈。
        :param pulumi.Input[builtins.str] isp: 线路类型，默认为BGP。BGP：BGP（多线）。1、若您的账号已申请并开通了静态单线权限，则可传入如下取值：1.1、ChinaMobile：中国移动静态单线。1.2、ChinaTelecom：中国电信静态单线。1.3、ChinaUnicom：中国联通静态单线。2、若您的账号已申请并开通了BGP单线权限，则可传入SingleLine*BGP。3、若您的账号已申请并开通了精品BGP权限，则可传入Premium*BGP。4、若您的账号已申请并开通了融合BGP权限，则可传入Fusion*BGP。5、若您的账号已申请并开通了惠选型静态单线权限，则可传入如下取值：5.1、ChinaMobile*Value：中国移动惠选型静态单线。5.2、ChinaUnicom*Value：中国联通惠选型静态单线。5.3、ChinaTelecom*Value：中国电信惠选型静态单线。
        :param pulumi.Input[builtins.int] period: 购买包年包月共享带宽包的时长，默认“1”。当PeriodUnit传入1，Period取值范围：1~9、12、24、36。当PeriodUnit传入2，Period取值范围：1～3。
        :param pulumi.Input[builtins.int] period_unit: 购买包年包月共享带宽包时长的单位，取值如下：1：月（默认值）。2 ：年。
        :param pulumi.Input[builtins.str] project_name: 项目名称，不填默认加入default项目。
        :param pulumi.Input[builtins.str] protocol: 共享带宽包的IP协议，取值如下：Dual-stack：双栈协议类型。IPv4：IPv4协议类型协议。仅BillingType传2或4时，本参数支持传入Dual-stack
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_protection_types: 共享带宽包的的安全防护类型。AntiDDoS_Enhanced：创建增强防护类型的共享带宽包，即创建支持添加基础防护类型公网IP的共享带宽包。不填则表示基础防护类型的共享带宽包，即创建支持添加增强防护类型公网IP的共享带宽包。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BandwidthPackageArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        共享带宽包是一种支持复用和共享带宽的云资源。将单个地域内多个公网IP或IPv6公网带宽添加到一个共享带宽包实例中，共享一条带宽。

        ## Import

        ```sh
        $ pulumi import bytepluscc:vpc/bandwidthPackage:BandwidthPackage example "bandwidth_package_id"
        ```

        :param str resource_name: The name of the resource.
        :param BandwidthPackageArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BandwidthPackageArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[builtins.int]] = None,
                 bandwidth_package_name: Optional[pulumi.Input[builtins.str]] = None,
                 billing_type: Optional[pulumi.Input[builtins.int]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 eip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BandwidthPackageEipAddressArgs', 'BandwidthPackageEipAddressArgsDict']]]]] = None,
                 enable_dual_stack: Optional[pulumi.Input[builtins.bool]] = None,
                 isp: Optional[pulumi.Input[builtins.str]] = None,
                 period: Optional[pulumi.Input[builtins.int]] = None,
                 period_unit: Optional[pulumi.Input[builtins.int]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 protocol: Optional[pulumi.Input[builtins.str]] = None,
                 security_protection_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BandwidthPackageTagArgs', 'BandwidthPackageTagArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BandwidthPackageArgs.__new__(BandwidthPackageArgs)

            if bandwidth is None and not opts.urn:
                raise TypeError("Missing required property 'bandwidth'")
            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["bandwidth_package_name"] = bandwidth_package_name
            __props__.__dict__["billing_type"] = billing_type
            __props__.__dict__["description"] = description
            __props__.__dict__["eip_addresses"] = eip_addresses
            __props__.__dict__["enable_dual_stack"] = enable_dual_stack
            __props__.__dict__["isp"] = isp
            __props__.__dict__["period"] = period
            __props__.__dict__["period_unit"] = period_unit
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["protocol"] = protocol
            __props__.__dict__["security_protection_types"] = security_protection_types
            __props__.__dict__["tags"] = tags
            __props__.__dict__["bandwidth_package_id"] = None
            __props__.__dict__["business_status"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["deleted_time"] = None
            __props__.__dict__["expired_time"] = None
            __props__.__dict__["overdue_time"] = None
            __props__.__dict__["ratio"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
        super(BandwidthPackage, __self__).__init__(
            'bytepluscc:vpc/bandwidthPackage:BandwidthPackage',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bandwidth: Optional[pulumi.Input[builtins.int]] = None,
            bandwidth_package_id: Optional[pulumi.Input[builtins.str]] = None,
            bandwidth_package_name: Optional[pulumi.Input[builtins.str]] = None,
            billing_type: Optional[pulumi.Input[builtins.int]] = None,
            business_status: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            deleted_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            eip_addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BandwidthPackageEipAddressArgs', 'BandwidthPackageEipAddressArgsDict']]]]] = None,
            enable_dual_stack: Optional[pulumi.Input[builtins.bool]] = None,
            expired_time: Optional[pulumi.Input[builtins.str]] = None,
            isp: Optional[pulumi.Input[builtins.str]] = None,
            overdue_time: Optional[pulumi.Input[builtins.str]] = None,
            period: Optional[pulumi.Input[builtins.int]] = None,
            period_unit: Optional[pulumi.Input[builtins.int]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            protocol: Optional[pulumi.Input[builtins.str]] = None,
            ratio: Optional[pulumi.Input[builtins.int]] = None,
            security_protection_types: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['BandwidthPackageTagArgs', 'BandwidthPackageTagArgsDict']]]]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None) -> 'BandwidthPackage':
        """
        Get an existing BandwidthPackage resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.int] bandwidth: 共享带宽包的带宽上限，单位：Mbps。BillingType传入1：取值范围5 ~ 5000，BillingType传入2、3、4：取值范围2 ~ 5000。
        :param pulumi.Input[builtins.str] bandwidth_package_id: 带宽包ID
        :param pulumi.Input[builtins.str] bandwidth_package_name: 带宽包名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        :param pulumi.Input[builtins.int] billing_type: 共享带宽包的计费方式。取值如下：1：包年包月。2 : 按带宽上限计费（默认值）。3：按主流量计费。4 : 按传统95计费（保底比例默认20%）。
        :param pulumi.Input[builtins.str] business_status: 计费状态
        :param pulumi.Input[builtins.str] created_time: 创建时间
        :param pulumi.Input[builtins.str] deleted_time: 删除时间
        :param pulumi.Input[builtins.str] description: 描述信息，长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        :param pulumi.Input[builtins.bool] enable_dual_stack: 是否启用双栈，取值如下：true：启用双栈。false：不启用双栈。
        :param pulumi.Input[builtins.str] expired_time: 过期时间
        :param pulumi.Input[builtins.str] isp: 线路类型，默认为BGP。BGP：BGP（多线）。1、若您的账号已申请并开通了静态单线权限，则可传入如下取值：1.1、ChinaMobile：中国移动静态单线。1.2、ChinaTelecom：中国电信静态单线。1.3、ChinaUnicom：中国联通静态单线。2、若您的账号已申请并开通了BGP单线权限，则可传入SingleLine*BGP。3、若您的账号已申请并开通了精品BGP权限，则可传入Premium*BGP。4、若您的账号已申请并开通了融合BGP权限，则可传入Fusion*BGP。5、若您的账号已申请并开通了惠选型静态单线权限，则可传入如下取值：5.1、ChinaMobile*Value：中国移动惠选型静态单线。5.2、ChinaUnicom*Value：中国联通惠选型静态单线。5.3、ChinaTelecom*Value：中国电信惠选型静态单线。
        :param pulumi.Input[builtins.str] overdue_time: 欠费时间
        :param pulumi.Input[builtins.int] period: 购买包年包月共享带宽包的时长，默认“1”。当PeriodUnit传入1，Period取值范围：1~9、12、24、36。当PeriodUnit传入2，Period取值范围：1～3。
        :param pulumi.Input[builtins.int] period_unit: 购买包年包月共享带宽包时长的单位，取值如下：1：月（默认值）。2 ：年。
        :param pulumi.Input[builtins.str] project_name: 项目名称，不填默认加入default项目。
        :param pulumi.Input[builtins.str] protocol: 共享带宽包的IP协议，取值如下：Dual-stack：双栈协议类型。IPv4：IPv4协议类型协议。仅BillingType传2或4时，本参数支持传入Dual-stack
        :param pulumi.Input[builtins.int] ratio: 95计费保底比例，单位%，仅95计费共享带宽包实例返回此参数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_protection_types: 共享带宽包的的安全防护类型。AntiDDoS_Enhanced：创建增强防护类型的共享带宽包，即创建支持添加基础防护类型公网IP的共享带宽包。不填则表示基础防护类型的共享带宽包，即创建支持添加增强防护类型公网IP的共享带宽包。
        :param pulumi.Input[builtins.str] status: 共享带宽包的状态。Creating：创建中。Available：可用。Deleting：删除中。
        :param pulumi.Input[builtins.str] updated_time: 更新时间
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BandwidthPackageState.__new__(_BandwidthPackageState)

        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["bandwidth_package_id"] = bandwidth_package_id
        __props__.__dict__["bandwidth_package_name"] = bandwidth_package_name
        __props__.__dict__["billing_type"] = billing_type
        __props__.__dict__["business_status"] = business_status
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["deleted_time"] = deleted_time
        __props__.__dict__["description"] = description
        __props__.__dict__["eip_addresses"] = eip_addresses
        __props__.__dict__["enable_dual_stack"] = enable_dual_stack
        __props__.__dict__["expired_time"] = expired_time
        __props__.__dict__["isp"] = isp
        __props__.__dict__["overdue_time"] = overdue_time
        __props__.__dict__["period"] = period
        __props__.__dict__["period_unit"] = period_unit
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["protocol"] = protocol
        __props__.__dict__["ratio"] = ratio
        __props__.__dict__["security_protection_types"] = security_protection_types
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["updated_time"] = updated_time
        return BandwidthPackage(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[builtins.int]:
        """
        共享带宽包的带宽上限，单位：Mbps。BillingType传入1：取值范围5 ~ 5000，BillingType传入2、3、4：取值范围2 ~ 5000。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> pulumi.Output[builtins.str]:
        """
        带宽包ID
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="bandwidthPackageName")
    def bandwidth_package_name(self) -> pulumi.Output[builtins.str]:
        """
        带宽包名称，长度限制为1 ~ 128个字符，需要以字母、中文或数字开头，可包含点号（.）、下划线（_）和短横线（-）。
        """
        return pulumi.get(self, "bandwidth_package_name")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> pulumi.Output[builtins.int]:
        """
        共享带宽包的计费方式。取值如下：1：包年包月。2 : 按带宽上限计费（默认值）。3：按主流量计费。4 : 按传统95计费（保底比例默认20%）。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter(name="businessStatus")
    def business_status(self) -> pulumi.Output[builtins.str]:
        """
        计费状态
        """
        return pulumi.get(self, "business_status")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="deletedTime")
    def deleted_time(self) -> pulumi.Output[builtins.str]:
        """
        删除时间
        """
        return pulumi.get(self, "deleted_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        描述信息，长度限制为0~ 255个字符。需要以字母、中文或数字开头。可包含英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eipAddresses")
    def eip_addresses(self) -> pulumi.Output[Sequence['outputs.BandwidthPackageEipAddress']]:
        return pulumi.get(self, "eip_addresses")

    @property
    @pulumi.getter(name="enableDualStack")
    def enable_dual_stack(self) -> pulumi.Output[builtins.bool]:
        """
        是否启用双栈，取值如下：true：启用双栈。false：不启用双栈。
        """
        return pulumi.get(self, "enable_dual_stack")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> pulumi.Output[builtins.str]:
        """
        过期时间
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter
    def isp(self) -> pulumi.Output[builtins.str]:
        """
        线路类型，默认为BGP。BGP：BGP（多线）。1、若您的账号已申请并开通了静态单线权限，则可传入如下取值：1.1、ChinaMobile：中国移动静态单线。1.2、ChinaTelecom：中国电信静态单线。1.3、ChinaUnicom：中国联通静态单线。2、若您的账号已申请并开通了BGP单线权限，则可传入SingleLine*BGP。3、若您的账号已申请并开通了精品BGP权限，则可传入Premium*BGP。4、若您的账号已申请并开通了融合BGP权限，则可传入Fusion*BGP。5、若您的账号已申请并开通了惠选型静态单线权限，则可传入如下取值：5.1、ChinaMobile*Value：中国移动惠选型静态单线。5.2、ChinaUnicom*Value：中国联通惠选型静态单线。5.3、ChinaTelecom*Value：中国电信惠选型静态单线。
        """
        return pulumi.get(self, "isp")

    @property
    @pulumi.getter(name="overdueTime")
    def overdue_time(self) -> pulumi.Output[builtins.str]:
        """
        欠费时间
        """
        return pulumi.get(self, "overdue_time")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[builtins.int]:
        """
        购买包年包月共享带宽包的时长，默认“1”。当PeriodUnit传入1，Period取值范围：1~9、12、24、36。当PeriodUnit传入2，Period取值范围：1～3。
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="periodUnit")
    def period_unit(self) -> pulumi.Output[builtins.int]:
        """
        购买包年包月共享带宽包时长的单位，取值如下：1：月（默认值）。2 ：年。
        """
        return pulumi.get(self, "period_unit")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        项目名称，不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def protocol(self) -> pulumi.Output[builtins.str]:
        """
        共享带宽包的IP协议，取值如下：Dual-stack：双栈协议类型。IPv4：IPv4协议类型协议。仅BillingType传2或4时，本参数支持传入Dual-stack
        """
        return pulumi.get(self, "protocol")

    @property
    @pulumi.getter
    def ratio(self) -> pulumi.Output[builtins.int]:
        """
        95计费保底比例，单位%，仅95计费共享带宽包实例返回此参数。
        """
        return pulumi.get(self, "ratio")

    @property
    @pulumi.getter(name="securityProtectionTypes")
    def security_protection_types(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        共享带宽包的的安全防护类型。AntiDDoS_Enhanced：创建增强防护类型的共享带宽包，即创建支持添加基础防护类型公网IP的共享带宽包。不填则表示基础防护类型的共享带宽包，即创建支持添加增强防护类型公网IP的共享带宽包。
        """
        return pulumi.get(self, "security_protection_types")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        共享带宽包的状态。Creating：创建中。Available：可用。Deleting：删除中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.BandwidthPackageTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间
        """
        return pulumi.get(self, "updated_time")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCommandResult',
    'AwaitableGetCommandResult',
    'get_command',
    'get_command_output',
]

@pulumi.output_type
class GetCommandResult:
    """
    A collection of values returned by getCommand.
    """
    def __init__(__self__, command_content=None, command_id=None, content_encoding=None, created_time=None, description=None, enable_parameter=None, id=None, invocation_times=None, name=None, parameter_definitions=None, project_name=None, provider_name=None, tags=None, timeout=None, type=None, updated_time=None, username=None, working_dir=None):
        if command_content and not isinstance(command_content, str):
            raise TypeError("Expected argument 'command_content' to be a str")
        pulumi.set(__self__, "command_content", command_content)
        if command_id and not isinstance(command_id, str):
            raise TypeError("Expected argument 'command_id' to be a str")
        pulumi.set(__self__, "command_id", command_id)
        if content_encoding and not isinstance(content_encoding, str):
            raise TypeError("Expected argument 'content_encoding' to be a str")
        pulumi.set(__self__, "content_encoding", content_encoding)
        if created_time and not isinstance(created_time, str):
            raise TypeError("Expected argument 'created_time' to be a str")
        pulumi.set(__self__, "created_time", created_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enable_parameter and not isinstance(enable_parameter, bool):
            raise TypeError("Expected argument 'enable_parameter' to be a bool")
        pulumi.set(__self__, "enable_parameter", enable_parameter)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if invocation_times and not isinstance(invocation_times, int):
            raise TypeError("Expected argument 'invocation_times' to be a int")
        pulumi.set(__self__, "invocation_times", invocation_times)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if parameter_definitions and not isinstance(parameter_definitions, list):
            raise TypeError("Expected argument 'parameter_definitions' to be a list")
        pulumi.set(__self__, "parameter_definitions", parameter_definitions)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if provider_name and not isinstance(provider_name, str):
            raise TypeError("Expected argument 'provider_name' to be a str")
        pulumi.set(__self__, "provider_name", provider_name)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if timeout and not isinstance(timeout, int):
            raise TypeError("Expected argument 'timeout' to be a int")
        pulumi.set(__self__, "timeout", timeout)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if updated_time and not isinstance(updated_time, str):
            raise TypeError("Expected argument 'updated_time' to be a str")
        pulumi.set(__self__, "updated_time", updated_time)
        if username and not isinstance(username, str):
            raise TypeError("Expected argument 'username' to be a str")
        pulumi.set(__self__, "username", username)
        if working_dir and not isinstance(working_dir, str):
            raise TypeError("Expected argument 'working_dir' to be a str")
        pulumi.set(__self__, "working_dir", working_dir)

    @property
    @pulumi.getter(name="commandContent")
    def command_content(self) -> builtins.str:
        """
        命令内容。请根据ContentEncoding参数传入相应命令内容。命令内容不能超过16KB。
        """
        return pulumi.get(self, "command_content")

    @property
    @pulumi.getter(name="commandId")
    def command_id(self) -> builtins.str:
        """
        自定义命令ID。
        """
        return pulumi.get(self, "command_id")

    @property
    @pulumi.getter(name="contentEncoding")
    def content_encoding(self) -> builtins.str:
        """
        命令内容是否经过Base64编码处理。Base64（默认）：经过Base64编码处理。PlainText： 未进行编码处理。
        """
        return pulumi.get(self, "content_encoding")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> builtins.str:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        命令描述，默认为空字符串。字符长度0~256。不限制特殊字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableParameter")
    def enable_parameter(self) -> builtins.bool:
        """
        创建的命令是否使用自定义参数。false：默认，表示不使用自定义参数。true：表示使用自定义参数。
        """
        return pulumi.get(self, "enable_parameter")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="invocationTimes")
    def invocation_times(self) -> builtins.int:
        """
        命令被调用次数。
        """
        return pulumi.get(self, "invocation_times")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        命令名称。字符长度1~32。不限制特殊字符。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="parameterDefinitions")
    def parameter_definitions(self) -> Sequence['outputs.GetCommandParameterDefinitionResult']:
        """
        自定义参数定义信息。
        """
        return pulumi.get(self, "parameter_definitions")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        资源所属项目，一个资源只能归属于一个项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="providerName")
    def provider_name(self) -> builtins.str:
        """
        命令的提供方。
        """
        return pulumi.get(self, "provider_name")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetCommandTagResult']:
        """
        标签键值对。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def timeout(self) -> builtins.int:
        """
        创建的命令在ECS实例中执行时最大的超时时间，单位为秒。取值范围：30~86400。默认值：60。
        """
        return pulumi.get(self, "timeout")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        命令的类型。Shell：表示创建一个在Linux实例中运行的Shell脚本。Python：表示创建一个Python脚本。Bat：表示创建一个Bat脚本。PowerShell：表示创建一个PowerShell脚本。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> builtins.str:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter
    def username(self) -> builtins.str:
        """
        执行命令时的用户名。
        """
        return pulumi.get(self, "username")

    @property
    @pulumi.getter(name="workingDir")
    def working_dir(self) -> builtins.str:
        """
        创建的命令在ECS实例中运行的目录。
        """
        return pulumi.get(self, "working_dir")


class AwaitableGetCommandResult(GetCommandResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCommandResult(
            command_content=self.command_content,
            command_id=self.command_id,
            content_encoding=self.content_encoding,
            created_time=self.created_time,
            description=self.description,
            enable_parameter=self.enable_parameter,
            id=self.id,
            invocation_times=self.invocation_times,
            name=self.name,
            parameter_definitions=self.parameter_definitions,
            project_name=self.project_name,
            provider_name=self.provider_name,
            tags=self.tags,
            timeout=self.timeout,
            type=self.type,
            updated_time=self.updated_time,
            username=self.username,
            working_dir=self.working_dir)


def get_command(id: Optional[builtins.str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCommandResult:
    """
    Data Source schema for Byteplus::ECS::Command


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:ecs/getCommand:getCommand', __args__, opts=opts, typ=GetCommandResult).value

    return AwaitableGetCommandResult(
        command_content=pulumi.get(__ret__, 'command_content'),
        command_id=pulumi.get(__ret__, 'command_id'),
        content_encoding=pulumi.get(__ret__, 'content_encoding'),
        created_time=pulumi.get(__ret__, 'created_time'),
        description=pulumi.get(__ret__, 'description'),
        enable_parameter=pulumi.get(__ret__, 'enable_parameter'),
        id=pulumi.get(__ret__, 'id'),
        invocation_times=pulumi.get(__ret__, 'invocation_times'),
        name=pulumi.get(__ret__, 'name'),
        parameter_definitions=pulumi.get(__ret__, 'parameter_definitions'),
        project_name=pulumi.get(__ret__, 'project_name'),
        provider_name=pulumi.get(__ret__, 'provider_name'),
        tags=pulumi.get(__ret__, 'tags'),
        timeout=pulumi.get(__ret__, 'timeout'),
        type=pulumi.get(__ret__, 'type'),
        updated_time=pulumi.get(__ret__, 'updated_time'),
        username=pulumi.get(__ret__, 'username'),
        working_dir=pulumi.get(__ret__, 'working_dir'))
def get_command_output(id: Optional[pulumi.Input[builtins.str]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetCommandResult]:
    """
    Data Source schema for Byteplus::ECS::Command


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:ecs/getCommand:getCommand', __args__, opts=opts, typ=GetCommandResult)
    return __ret__.apply(lambda __response__: GetCommandResult(
        command_content=pulumi.get(__response__, 'command_content'),
        command_id=pulumi.get(__response__, 'command_id'),
        content_encoding=pulumi.get(__response__, 'content_encoding'),
        created_time=pulumi.get(__response__, 'created_time'),
        description=pulumi.get(__response__, 'description'),
        enable_parameter=pulumi.get(__response__, 'enable_parameter'),
        id=pulumi.get(__response__, 'id'),
        invocation_times=pulumi.get(__response__, 'invocation_times'),
        name=pulumi.get(__response__, 'name'),
        parameter_definitions=pulumi.get(__response__, 'parameter_definitions'),
        project_name=pulumi.get(__response__, 'project_name'),
        provider_name=pulumi.get(__response__, 'provider_name'),
        tags=pulumi.get(__response__, 'tags'),
        timeout=pulumi.get(__response__, 'timeout'),
        type=pulumi.get(__response__, 'type'),
        updated_time=pulumi.get(__response__, 'updated_time'),
        username=pulumi.get(__response__, 'username'),
        working_dir=pulumi.get(__response__, 'working_dir')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetServerGroupResult',
    'AwaitableGetServerGroupResult',
    'get_server_group',
    'get_server_group_output',
]

@pulumi.output_type
class GetServerGroupResult:
    """
    A collection of values returned by getServerGroup.
    """
    def __init__(__self__, address_ip_version=None, any_port_enabled=None, create_time=None, description=None, id=None, listeners=None, load_balancer_id=None, server_group_id=None, server_group_name=None, servers=None, tags=None, type=None, update_time=None):
        if address_ip_version and not isinstance(address_ip_version, str):
            raise TypeError("Expected argument 'address_ip_version' to be a str")
        pulumi.set(__self__, "address_ip_version", address_ip_version)
        if any_port_enabled and not isinstance(any_port_enabled, str):
            raise TypeError("Expected argument 'any_port_enabled' to be a str")
        pulumi.set(__self__, "any_port_enabled", any_port_enabled)
        if create_time and not isinstance(create_time, str):
            raise TypeError("Expected argument 'create_time' to be a str")
        pulumi.set(__self__, "create_time", create_time)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if listeners and not isinstance(listeners, list):
            raise TypeError("Expected argument 'listeners' to be a list")
        pulumi.set(__self__, "listeners", listeners)
        if load_balancer_id and not isinstance(load_balancer_id, str):
            raise TypeError("Expected argument 'load_balancer_id' to be a str")
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if server_group_id and not isinstance(server_group_id, str):
            raise TypeError("Expected argument 'server_group_id' to be a str")
        pulumi.set(__self__, "server_group_id", server_group_id)
        if server_group_name and not isinstance(server_group_name, str):
            raise TypeError("Expected argument 'server_group_name' to be a str")
        pulumi.set(__self__, "server_group_name", server_group_name)
        if servers and not isinstance(servers, list):
            raise TypeError("Expected argument 'servers' to be a list")
        pulumi.set(__self__, "servers", servers)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if update_time and not isinstance(update_time, str):
            raise TypeError("Expected argument 'update_time' to be a str")
        pulumi.set(__self__, "update_time", update_time)

    @property
    @pulumi.getter(name="addressIpVersion")
    def address_ip_version(self) -> builtins.str:
        """
        后端服务器组的IP地址类型。ipv4：后端服务器组为IPv4类型。ipv6：后端服务器组为IPv6类型。
        """
        return pulumi.get(self, "address_ip_version")

    @property
    @pulumi.getter(name="anyPortEnabled")
    def any_port_enabled(self) -> builtins.str:
        """
        是否开启全端口转发。on：开启全端口转发。off：关闭全端口转发。
        """
        return pulumi.get(self, "any_port_enabled")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> builtins.str:
        """
        后端服务器组的创建时间。
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        后端服务器组的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个符。不填则默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def listeners(self) -> Sequence['outputs.GetServerGroupListenerResult']:
        """
        后端服务器组关联的监听器信息。
        """
        return pulumi.get(self, "listeners")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> builtins.str:
        """
        后端服务器组所属的CLB实例ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> builtins.str:
        """
        后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter(name="serverGroupName")
    def server_group_name(self) -> builtins.str:
        """
        后端服务器组的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线（_）和中划线（-）。限制为1 ～ 128个字符。不填默认为后端服务器组ID。
        """
        return pulumi.get(self, "server_group_name")

    @property
    @pulumi.getter
    def servers(self) -> Sequence['outputs.GetServerGroupServerResult']:
        """
        后端服务器组中服务器的信息。
        """
        return pulumi.get(self, "servers")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetServerGroupTagResult']:
        """
        标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        后端服务器组的类型。instance：表示该后端服务器组只能添加云服务器的主网卡或辅助网卡作为后端服务器。ip：表示该后端服务器组只能添加IP地址作为后端服务器。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="updateTime")
    def update_time(self) -> builtins.str:
        """
        后端服务器组的最近操作时间。
        """
        return pulumi.get(self, "update_time")


class AwaitableGetServerGroupResult(GetServerGroupResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetServerGroupResult(
            address_ip_version=self.address_ip_version,
            any_port_enabled=self.any_port_enabled,
            create_time=self.create_time,
            description=self.description,
            id=self.id,
            listeners=self.listeners,
            load_balancer_id=self.load_balancer_id,
            server_group_id=self.server_group_id,
            server_group_name=self.server_group_name,
            servers=self.servers,
            tags=self.tags,
            type=self.type,
            update_time=self.update_time)


def get_server_group(id: Optional[builtins.str] = None,
                     opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetServerGroupResult:
    """
    Data Source schema for Byteplus::CLB::ServerGroup


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:clb/getServerGroup:getServerGroup', __args__, opts=opts, typ=GetServerGroupResult).value

    return AwaitableGetServerGroupResult(
        address_ip_version=pulumi.get(__ret__, 'address_ip_version'),
        any_port_enabled=pulumi.get(__ret__, 'any_port_enabled'),
        create_time=pulumi.get(__ret__, 'create_time'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        listeners=pulumi.get(__ret__, 'listeners'),
        load_balancer_id=pulumi.get(__ret__, 'load_balancer_id'),
        server_group_id=pulumi.get(__ret__, 'server_group_id'),
        server_group_name=pulumi.get(__ret__, 'server_group_name'),
        servers=pulumi.get(__ret__, 'servers'),
        tags=pulumi.get(__ret__, 'tags'),
        type=pulumi.get(__ret__, 'type'),
        update_time=pulumi.get(__ret__, 'update_time'))
def get_server_group_output(id: Optional[pulumi.Input[builtins.str]] = None,
                            opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetServerGroupResult]:
    """
    Data Source schema for Byteplus::CLB::ServerGroup


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:clb/getServerGroup:getServerGroup', __args__, opts=opts, typ=GetServerGroupResult)
    return __ret__.apply(lambda __response__: GetServerGroupResult(
        address_ip_version=pulumi.get(__response__, 'address_ip_version'),
        any_port_enabled=pulumi.get(__response__, 'any_port_enabled'),
        create_time=pulumi.get(__response__, 'create_time'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        listeners=pulumi.get(__response__, 'listeners'),
        load_balancer_id=pulumi.get(__response__, 'load_balancer_id'),
        server_group_id=pulumi.get(__response__, 'server_group_id'),
        server_group_name=pulumi.get(__response__, 'server_group_name'),
        servers=pulumi.get(__response__, 'servers'),
        tags=pulumi.get(__response__, 'tags'),
        type=pulumi.get(__response__, 'type'),
        update_time=pulumi.get(__response__, 'update_time')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'WorkspaceInstanceTypeArgs',
    'WorkspaceInstanceTypeArgsDict',
    'WorkspaceQuotaArgs',
    'WorkspaceQuotaArgsDict',
    'WorkspaceTagArgs',
    'WorkspaceTagArgsDict',
    'WorkspaceUsageArgs',
    'WorkspaceUsageArgsDict',
]

MYPY = False

if not MYPY:
    class WorkspaceInstanceTypeArgsDict(TypedDict):
        active_series: NotRequired[pulumi.Input[builtins.int]]
        """
        最大活跃时序数。
        """
        availability_zone_replicas: NotRequired[pulumi.Input[builtins.int]]
        """
        可用区（az）数。
        """
        downsampling_periods: NotRequired[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]
        """
        降采样策略。
        """
        ingest_samples_per_second: NotRequired[pulumi.Input[builtins.int]]
        """
        最大每秒写入样本数。
        """
        query_concurrency: NotRequired[pulumi.Input[builtins.int]]
        """
        最大查询并发数。
        """
        query_per_second: NotRequired[pulumi.Input[builtins.int]]
        """
        最大查询 QPS。
        """
        replicas_per_zone: NotRequired[pulumi.Input[builtins.int]]
        """
        每个可用区（az）的数据副本数。
        """
        retention_period: NotRequired[pulumi.Input[builtins.str]]
        """
        最长数据保留时间。
        """
        scan_samples_per_second: NotRequired[pulumi.Input[builtins.int]]
        """
        最大每秒扫描样本数。
        """
        scan_series_per_second: NotRequired[pulumi.Input[builtins.int]]
        """
        最大每秒扫描时序数。
        """
elif False:
    WorkspaceInstanceTypeArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkspaceInstanceTypeArgs:
    def __init__(__self__, *,
                 active_series: Optional[pulumi.Input[builtins.int]] = None,
                 availability_zone_replicas: Optional[pulumi.Input[builtins.int]] = None,
                 downsampling_periods: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 ingest_samples_per_second: Optional[pulumi.Input[builtins.int]] = None,
                 query_concurrency: Optional[pulumi.Input[builtins.int]] = None,
                 query_per_second: Optional[pulumi.Input[builtins.int]] = None,
                 replicas_per_zone: Optional[pulumi.Input[builtins.int]] = None,
                 retention_period: Optional[pulumi.Input[builtins.str]] = None,
                 scan_samples_per_second: Optional[pulumi.Input[builtins.int]] = None,
                 scan_series_per_second: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.int] active_series: 最大活跃时序数。
        :param pulumi.Input[builtins.int] availability_zone_replicas: 可用区（az）数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] downsampling_periods: 降采样策略。
        :param pulumi.Input[builtins.int] ingest_samples_per_second: 最大每秒写入样本数。
        :param pulumi.Input[builtins.int] query_concurrency: 最大查询并发数。
        :param pulumi.Input[builtins.int] query_per_second: 最大查询 QPS。
        :param pulumi.Input[builtins.int] replicas_per_zone: 每个可用区（az）的数据副本数。
        :param pulumi.Input[builtins.str] retention_period: 最长数据保留时间。
        :param pulumi.Input[builtins.int] scan_samples_per_second: 最大每秒扫描样本数。
        :param pulumi.Input[builtins.int] scan_series_per_second: 最大每秒扫描时序数。
        """
        if active_series is not None:
            pulumi.set(__self__, "active_series", active_series)
        if availability_zone_replicas is not None:
            pulumi.set(__self__, "availability_zone_replicas", availability_zone_replicas)
        if downsampling_periods is not None:
            pulumi.set(__self__, "downsampling_periods", downsampling_periods)
        if ingest_samples_per_second is not None:
            pulumi.set(__self__, "ingest_samples_per_second", ingest_samples_per_second)
        if query_concurrency is not None:
            pulumi.set(__self__, "query_concurrency", query_concurrency)
        if query_per_second is not None:
            pulumi.set(__self__, "query_per_second", query_per_second)
        if replicas_per_zone is not None:
            pulumi.set(__self__, "replicas_per_zone", replicas_per_zone)
        if retention_period is not None:
            pulumi.set(__self__, "retention_period", retention_period)
        if scan_samples_per_second is not None:
            pulumi.set(__self__, "scan_samples_per_second", scan_samples_per_second)
        if scan_series_per_second is not None:
            pulumi.set(__self__, "scan_series_per_second", scan_series_per_second)

    @property
    @pulumi.getter(name="activeSeries")
    def active_series(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大活跃时序数。
        """
        return pulumi.get(self, "active_series")

    @active_series.setter
    def active_series(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "active_series", value)

    @property
    @pulumi.getter(name="availabilityZoneReplicas")
    def availability_zone_replicas(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        可用区（az）数。
        """
        return pulumi.get(self, "availability_zone_replicas")

    @availability_zone_replicas.setter
    def availability_zone_replicas(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "availability_zone_replicas", value)

    @property
    @pulumi.getter(name="downsamplingPeriods")
    def downsampling_periods(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        降采样策略。
        """
        return pulumi.get(self, "downsampling_periods")

    @downsampling_periods.setter
    def downsampling_periods(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "downsampling_periods", value)

    @property
    @pulumi.getter(name="ingestSamplesPerSecond")
    def ingest_samples_per_second(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大每秒写入样本数。
        """
        return pulumi.get(self, "ingest_samples_per_second")

    @ingest_samples_per_second.setter
    def ingest_samples_per_second(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ingest_samples_per_second", value)

    @property
    @pulumi.getter(name="queryConcurrency")
    def query_concurrency(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大查询并发数。
        """
        return pulumi.get(self, "query_concurrency")

    @query_concurrency.setter
    def query_concurrency(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "query_concurrency", value)

    @property
    @pulumi.getter(name="queryPerSecond")
    def query_per_second(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大查询 QPS。
        """
        return pulumi.get(self, "query_per_second")

    @query_per_second.setter
    def query_per_second(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "query_per_second", value)

    @property
    @pulumi.getter(name="replicasPerZone")
    def replicas_per_zone(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        每个可用区（az）的数据副本数。
        """
        return pulumi.get(self, "replicas_per_zone")

    @replicas_per_zone.setter
    def replicas_per_zone(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "replicas_per_zone", value)

    @property
    @pulumi.getter(name="retentionPeriod")
    def retention_period(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        最长数据保留时间。
        """
        return pulumi.get(self, "retention_period")

    @retention_period.setter
    def retention_period(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "retention_period", value)

    @property
    @pulumi.getter(name="scanSamplesPerSecond")
    def scan_samples_per_second(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大每秒扫描样本数。
        """
        return pulumi.get(self, "scan_samples_per_second")

    @scan_samples_per_second.setter
    def scan_samples_per_second(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "scan_samples_per_second", value)

    @property
    @pulumi.getter(name="scanSeriesPerSecond")
    def scan_series_per_second(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大每秒扫描时序数。
        """
        return pulumi.get(self, "scan_series_per_second")

    @scan_series_per_second.setter
    def scan_series_per_second(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "scan_series_per_second", value)


if not MYPY:
    class WorkspaceQuotaArgsDict(TypedDict):
        active_series: NotRequired[pulumi.Input[builtins.int]]
        """
        最大活跃时序数。整数形式，默认取值范围为 1～50000000。
        """
        ingest_samples_per_second: NotRequired[pulumi.Input[builtins.int]]
        """
        指标摄入速率，即最大每秒写入样本数。整数形式，默认取值范围为 1～5000000。
        """
        query_per_second: NotRequired[pulumi.Input[builtins.int]]
        """
        最大查询 QPS。整数形式，默认取值范围为 1～500。
        """
        scan_samples_per_second: NotRequired[pulumi.Input[builtins.int]]
        """
        最大每秒扫描样本数。整数形式，默认取值范围为 1～1000000000。
        """
        scan_series_per_second: NotRequired[pulumi.Input[builtins.int]]
        """
        最大每秒扫描时序数。整数形式，默认取值范围为 1～200000。
        """
elif False:
    WorkspaceQuotaArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkspaceQuotaArgs:
    def __init__(__self__, *,
                 active_series: Optional[pulumi.Input[builtins.int]] = None,
                 ingest_samples_per_second: Optional[pulumi.Input[builtins.int]] = None,
                 query_per_second: Optional[pulumi.Input[builtins.int]] = None,
                 scan_samples_per_second: Optional[pulumi.Input[builtins.int]] = None,
                 scan_series_per_second: Optional[pulumi.Input[builtins.int]] = None):
        """
        :param pulumi.Input[builtins.int] active_series: 最大活跃时序数。整数形式，默认取值范围为 1～50000000。
        :param pulumi.Input[builtins.int] ingest_samples_per_second: 指标摄入速率，即最大每秒写入样本数。整数形式，默认取值范围为 1～5000000。
        :param pulumi.Input[builtins.int] query_per_second: 最大查询 QPS。整数形式，默认取值范围为 1～500。
        :param pulumi.Input[builtins.int] scan_samples_per_second: 最大每秒扫描样本数。整数形式，默认取值范围为 1～1000000000。
        :param pulumi.Input[builtins.int] scan_series_per_second: 最大每秒扫描时序数。整数形式，默认取值范围为 1～200000。
        """
        if active_series is not None:
            pulumi.set(__self__, "active_series", active_series)
        if ingest_samples_per_second is not None:
            pulumi.set(__self__, "ingest_samples_per_second", ingest_samples_per_second)
        if query_per_second is not None:
            pulumi.set(__self__, "query_per_second", query_per_second)
        if scan_samples_per_second is not None:
            pulumi.set(__self__, "scan_samples_per_second", scan_samples_per_second)
        if scan_series_per_second is not None:
            pulumi.set(__self__, "scan_series_per_second", scan_series_per_second)

    @property
    @pulumi.getter(name="activeSeries")
    def active_series(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大活跃时序数。整数形式，默认取值范围为 1～50000000。
        """
        return pulumi.get(self, "active_series")

    @active_series.setter
    def active_series(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "active_series", value)

    @property
    @pulumi.getter(name="ingestSamplesPerSecond")
    def ingest_samples_per_second(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        指标摄入速率，即最大每秒写入样本数。整数形式，默认取值范围为 1～5000000。
        """
        return pulumi.get(self, "ingest_samples_per_second")

    @ingest_samples_per_second.setter
    def ingest_samples_per_second(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "ingest_samples_per_second", value)

    @property
    @pulumi.getter(name="queryPerSecond")
    def query_per_second(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大查询 QPS。整数形式，默认取值范围为 1～500。
        """
        return pulumi.get(self, "query_per_second")

    @query_per_second.setter
    def query_per_second(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "query_per_second", value)

    @property
    @pulumi.getter(name="scanSamplesPerSecond")
    def scan_samples_per_second(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大每秒扫描样本数。整数形式，默认取值范围为 1～1000000000。
        """
        return pulumi.get(self, "scan_samples_per_second")

    @scan_samples_per_second.setter
    def scan_samples_per_second(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "scan_samples_per_second", value)

    @property
    @pulumi.getter(name="scanSeriesPerSecond")
    def scan_series_per_second(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        最大每秒扫描时序数。整数形式，默认取值范围为 1～200000。
        """
        return pulumi.get(self, "scan_series_per_second")

    @scan_series_per_second.setter
    def scan_series_per_second(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "scan_series_per_second", value)


if not MYPY:
    class WorkspaceTagArgsDict(TypedDict):
        key: NotRequired[pulumi.Input[builtins.str]]
        """
        标签键。
        """
        value: NotRequired[pulumi.Input[builtins.str]]
        """
        标签值。
        """
elif False:
    WorkspaceTagArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkspaceTagArgs:
    def __init__(__self__, *,
                 key: Optional[pulumi.Input[builtins.str]] = None,
                 value: Optional[pulumi.Input[builtins.str]] = None):
        """
        :param pulumi.Input[builtins.str] key: 标签键。
        :param pulumi.Input[builtins.str] value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @key.setter
    def key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "key", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        标签值。
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "value", value)


if not MYPY:
    class WorkspaceUsageArgsDict(TypedDict):
        active_series: NotRequired[pulumi.Input[builtins.int]]
        """
        活跃时序数。
        """
        ingested_samples_per_second: NotRequired[pulumi.Input[builtins.float]]
        """
        每秒写入样本数。
        """
elif False:
    WorkspaceUsageArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class WorkspaceUsageArgs:
    def __init__(__self__, *,
                 active_series: Optional[pulumi.Input[builtins.int]] = None,
                 ingested_samples_per_second: Optional[pulumi.Input[builtins.float]] = None):
        """
        :param pulumi.Input[builtins.int] active_series: 活跃时序数。
        :param pulumi.Input[builtins.float] ingested_samples_per_second: 每秒写入样本数。
        """
        if active_series is not None:
            pulumi.set(__self__, "active_series", active_series)
        if ingested_samples_per_second is not None:
            pulumi.set(__self__, "ingested_samples_per_second", ingested_samples_per_second)

    @property
    @pulumi.getter(name="activeSeries")
    def active_series(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        活跃时序数。
        """
        return pulumi.get(self, "active_series")

    @active_series.setter
    def active_series(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "active_series", value)

    @property
    @pulumi.getter(name="ingestedSamplesPerSecond")
    def ingested_samples_per_second(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        每秒写入样本数。
        """
        return pulumi.get(self, "ingested_samples_per_second")

    @ingested_samples_per_second.setter
    def ingested_samples_per_second(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "ingested_samples_per_second", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'InstanceCachePerformance',
    'InstanceCapacity',
    'InstanceTag',
    'GetInstanceCachePerformanceResult',
    'GetInstanceCapacityResult',
    'GetInstanceTagResult',
]

@pulumi.output_type
class InstanceCachePerformance(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "cacheBandwidth":
            suggest = "cache_bandwidth"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in InstanceCachePerformance. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        InstanceCachePerformance.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        InstanceCachePerformance.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 cache_bandwidth: Optional[builtins.int] = None):
        """
        :param builtins.int cache_bandwidth: 预配置带宽，用于增加文件系统带宽。
        """
        if cache_bandwidth is not None:
            pulumi.set(__self__, "cache_bandwidth", cache_bandwidth)

    @property
    @pulumi.getter(name="cacheBandwidth")
    def cache_bandwidth(self) -> Optional[builtins.int]:
        """
        预配置带宽，用于增加文件系统带宽。
        """
        return pulumi.get(self, "cache_bandwidth")


@pulumi.output_type
class InstanceCapacity(dict):
    def __init__(__self__, *,
                 total: Optional[builtins.float] = None,
                 used: Optional[builtins.float] = None):
        """
        :param builtins.float total: 文件系统可用总容量，单位为 GiB。
        :param builtins.float used: 文件系统已使用容量，单位为 MiB。
        """
        if total is not None:
            pulumi.set(__self__, "total", total)
        if used is not None:
            pulumi.set(__self__, "used", used)

    @property
    @pulumi.getter
    def total(self) -> Optional[builtins.float]:
        """
        文件系统可用总容量，单位为 GiB。
        """
        return pulumi.get(self, "total")

    @property
    @pulumi.getter
    def used(self) -> Optional[builtins.float]:
        """
        文件系统已使用容量，单位为 MiB。
        """
        return pulumi.get(self, "used")


@pulumi.output_type
class InstanceTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 type: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str type: 标签类型。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        标签类型。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInstanceCachePerformanceResult(dict):
    def __init__(__self__, *,
                 cache_bandwidth: builtins.int):
        """
        :param builtins.int cache_bandwidth: 预配置带宽，用于增加文件系统带宽。
        """
        pulumi.set(__self__, "cache_bandwidth", cache_bandwidth)

    @property
    @pulumi.getter(name="cacheBandwidth")
    def cache_bandwidth(self) -> builtins.int:
        """
        预配置带宽，用于增加文件系统带宽。
        """
        return pulumi.get(self, "cache_bandwidth")


@pulumi.output_type
class GetInstanceCapacityResult(dict):
    def __init__(__self__, *,
                 total: builtins.float,
                 used: builtins.float):
        """
        :param builtins.float total: 文件系统可用总容量，单位为 GiB。
        :param builtins.float used: 文件系统已使用容量，单位为 MiB。
        """
        pulumi.set(__self__, "total", total)
        pulumi.set(__self__, "used", used)

    @property
    @pulumi.getter
    def total(self) -> builtins.float:
        """
        文件系统可用总容量，单位为 GiB。
        """
        return pulumi.get(self, "total")

    @property
    @pulumi.getter
    def used(self) -> builtins.float:
        """
        文件系统已使用容量，单位为 MiB。
        """
        return pulumi.get(self, "used")


@pulumi.output_type
class GetInstanceTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 type: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str type: 标签类型。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        标签类型。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


